@@ -39,10 +39,11 @@ limitations under the License.
 #include "chisel.h"
 #include "chisel_utils.h"
 #endif
-#include "fields_info.h"
-#include "table.h"
+#include "chisel_table.h"
 #include "utils.h"
-#include "plugin_utils.h"
+#include "utils/plugin_utils.h"
+#include "utils/sinsp_opener.h"
+#include "utils/supported_fields.h"
 
 #ifdef _WIN32
 #include "win32/getopt.h"
@@ -57,7 +58,7 @@ limitations under the License.
 #include "cursestable.h"
 #include "cursesui.h"
 #include "scap_open_exception.h"
-#include "sinsp_capture_interrupt_exception.h"
+#include "chisel_capture_interrupt_exception.h"
 
 #define MOUSE_CAPABLE_TERM "xterm-1003"
 #define MOUSE_CAPABLE_TERM_COMPAT "xterm-1002"
@@ -108,11 +109,23 @@ static void usage()
 " -A, --print-ascii  When emitting JSON, only print the text portion of data buffers, and echo\n"
 "                    end-of-lines. This is useful to only display human-readable\n"
 "                    data.\n"
+#ifdef HAS_MODERN_BPF
+" --modern-bpf\n"
+"                    Enable live capture using the modern BPF probe instead of the kernel module.\n"
+#endif
 " -B<bpf_probe>, --bpf=<bpf_probe>\n"
 "                    Enable live capture using the specified BPF probe instead of the kernel module.\n"
 "                    The BPF probe can also be specified via the environment variable\n"
 "                    SYSDIG_BPF_PROBE. If <bpf_probe> is left empty, sysdig will\n"
 "                    try to load one from the scap-driver-loader script.\n"
+#ifdef HAS_MODERN_BPF
+"  --cpus-for-each-buffer <cpus_num>\n"
+"                    Please note this config regards only the modern BPF probe.\n"
+"                    How many CPUs you want to assign to a single syscall buffer (ring buffer).\n"
+"                    By default, every syscall buffer is associated to 2 CPUs, so the mapping is\n"
+"                    1:2. The modern BPF probe allows you to choose different mappings, for\n"
+"                    example, 1:1 would mean a syscall buffer for each CPU.\n"
+#endif
 #ifdef HAS_CAPTURE
 " --cri <path>       Path to CRI socket for container metadata\n"
 "                    Use the specified socket to fetch data from a CRI-compatible runtime\n"
@@ -229,7 +242,7 @@ static void add_chisel_dirs(sinsp* inspector)
 
 	if(s_user_cdirs != NULL)
 	{
-		vector<string> user_cdirs = sinsp_split(s_user_cdirs, ';');
+		std::vector<std::string> user_cdirs = sinsp_split(s_user_cdirs, ';');
 
 		for(uint32_t j = 0; j < user_cdirs.size(); j++)
 		{
@@ -238,17 +251,17 @@ static void add_chisel_dirs(sinsp* inspector)
 	}
 }
 
-static void print_views(sinsp_view_manager* view_manager)
+static void print_views(chisel_view_manager* view_manager)
 {
 	Json::FastWriter writer;
 	Json::Value root;
 
-	vector<sinsp_view_info>* vlist = view_manager->get_views();
+	std::vector<chisel_view_info>* vlist = view_manager->get_views();
 
 	for(auto it = vlist->begin(); it != vlist->end(); ++it)
 	{
 		Json::Value jv;
-		sinsp_view_info& vinfo = *it;
+		chisel_view_info& vinfo = *it;
 
 		jv["id"] = vinfo.m_id;
 		jv["name"] = vinfo.m_name;
@@ -256,7 +269,7 @@ static void print_views(sinsp_view_manager* view_manager)
 		jv["isRoot"] = vinfo.m_is_root;
 		jv["drilldownTarget"] = vinfo.m_drilldown_target;
 		jv["filter"] = vinfo.m_filter;
-		jv["canDrillDown"] = (vinfo.m_type == sinsp_view_info::T_TABLE);
+		jv["canDrillDown"] = (vinfo.m_type == chisel_view_info::T_TABLE);
 
 		for(auto it = vinfo.m_applies_to.begin(); it != vinfo.m_applies_to.end(); ++it)
 		{
@@ -274,7 +287,7 @@ static void print_views(sinsp_view_manager* view_manager)
 		root.append(jv);
 	}
 
-	string output = writer.write(root);
+	std::string output = writer.write(root);
 	printf("%s", output.substr(0, output.size() - 1).c_str());
 }
 #endif
@@ -287,6 +300,7 @@ captureinfo do_inspect(sinsp* inspector,
 	int32_t res;
 	sinsp_evt* ev;
 
+	inspector->start_capture();
 	//
 	// Loop through the events
 	//
@@ -303,7 +317,7 @@ captureinfo do_inspect(sinsp* inspector,
 
 		res = inspector->next(&ev);
 
-		if(res == SCAP_TIMEOUT)
+		if(res == SCAP_TIMEOUT || res == SCAP_FILTERED_EVENT)
 		{
 			continue;
 		}
@@ -331,25 +345,25 @@ captureinfo do_inspect(sinsp* inspector,
 
 		retval.m_nevts++;
 	}
-
+	inspector->stop_capture();
 	return retval;
 }
 
-string g_version_string = SYSDIG_VERSION;
+std::string g_version_string = SYSDIG_VERSION;
 
 sysdig_init_res csysdig_init(int argc, char **argv)
 {
 	sysdig_init_res res;
 	sinsp* inspector = NULL;
-	vector<string> infiles;
+	std::vector<std::string> infiles;
 	int op;
 	uint64_t cnt = -1;
 	uint32_t snaplen = 0;
 	int long_index = 0;
 	int32_t n_filterargs = 0;
 	captureinfo cinfo;
-	string errorstr;
-	string display_view;
+	std::string errorstr;
+	std::string display_view;
 	bool print_containers = false;
 	uint64_t refresh_interval_ns = 2000000000;
 	bool list_flds = false;
@@ -358,33 +372,36 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 	int32_t json_last_row = 0;
 	int32_t sorting_col = -1;
 	bool list_views = false;
-	bool bpf = false;
-	string bpf_probe;
 #ifdef HAS_CAPTURE
-	string cri_socket_path;
+	std::string cri_socket_path;
 #endif
 
 #ifndef _WIN32
-	sinsp_table::output_type output_type = sinsp_table::OT_CURSES;
+	chisel_table::output_type output_type = chisel_table::OT_CURSES;
 #else
-	sinsp_table::output_type output_type = sinsp_table::OT_JSON;
+	chisel_table::output_type output_type = chisel_table::OT_JSON;
 #endif
 #ifndef MINIMAL_BUILD
-	string* k8s_api = 0;
-	string* node_name = 0;
-	string* k8s_api_cert = 0;
-	string* mesos_api = 0;
+	std::string* k8s_api = 0;
+	std::string* node_name = 0;
+	std::string* k8s_api_cert = 0;
+	std::string* mesos_api = 0;
 #endif // MINIMAL_BUILD
 	bool terminal_with_mouse = false;
 	bool force_tracers_capture = false;
 	bool force_term_compat = false;
 	sinsp_evt::param_fmt event_buffer_format = sinsp_evt::PF_NORMAL;
-	bool page_faults = false;
+	plugin_utils plugins;
+	bool list_plugins = false;
+	sinsp_opener opener;
 
 	static struct option long_options[] =
 	{
 		{"print-ascii", no_argument, 0, 'A' },
 		{"bpf", optional_argument, 0, 'B' },
+#ifdef HAS_MODERN_BPF
+		{"cpus-for-each-buffer", required_argument, 0, 0 },
+#endif
 #ifdef HAS_CAPTURE
 		{"cri", required_argument, 0, 0 },
 		{"cri-timeout", required_argument, 0, 0 },
@@ -406,6 +423,9 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 #ifndef MINIMAL_BUILD
 		{"mesos-api", required_argument, 0, 'm'},
 #endif // MINIMAL_BUILD
+#ifdef HAS_MODERN_BPF
+		{"modern-bpf", no_argument, 0, 0 },
+#endif
 		{"numevents", required_argument, 0, 'n' },
 		{"page-faults", no_argument, 0, 0 },
 		{"print", required_argument, 0, 'p' },
@@ -434,8 +454,8 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 #ifdef HAS_CHISELS
 		add_chisel_dirs(inspector);
 #endif
-		add_plugin_dirs(SYSDIG_PLUGINS_DIR);
-		init_plugins(inspector);
+		plugins.add_directory(SYSDIG_PLUGINS_DIR);
+		plugins.read_plugins_from_dirs(inspector);
 
 		//
 		// Parse the args
@@ -463,10 +483,10 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				break;
 			case 'B':
 			{
-				bpf = true;
+				opener.bpf.enabled = true;
 				if(optarg)
 				{
-					bpf_probe = optarg;
+					opener.bpf.probe = optarg;
 				}
 				break;
 			}
@@ -495,24 +515,24 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				return sysdig_init_res(EXIT_SUCCESS);
 #ifndef MINIMAL_BUILD
 			case 'k':
-				k8s_api = new string(optarg);
+				k8s_api = new std::string(optarg);
 				break;
 			case 'N':
-				node_name = new string(optarg);
+				node_name = new std::string(optarg);
 				break;
 			case 'K':
-				k8s_api_cert = new string(optarg);
+				k8s_api_cert = new std::string(optarg);
 				break;
 #endif // MINIMAL_BUILD
 			case 'j':
-				output_type = sinsp_table::OT_JSON;
+				output_type = chisel_table::OT_JSON;
 				break;
 			case 'l':
 				list_flds = true;
 				break;
 #ifndef MINIMAL_BUILD
 			case 'm':
-				mesos_api = new string(optarg);
+				mesos_api = new std::string(optarg);
 				break;
 #endif // MINIMAL_BUILD
 			case 'n':
@@ -527,13 +547,13 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 
 				if(cnt <= 0)
 				{
-					throw sinsp_exception(string("invalid event count ") + optarg);
+					throw sinsp_exception(std::string("invalid event count ") + optarg);
 					res.m_res = EXIT_FAILURE;
 					goto exit;
 				}
 				break;
 			case 'p':
-				if(string(optarg) == "c" || string(optarg) == "container")
+				if(std::string(optarg) == "c" || std::string(optarg) == "container")
 				{
 					inspector->set_print_container_data(true);
 					print_containers = true;
@@ -546,8 +566,8 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 			case 'r':
 				infiles.push_back(optarg);
 #ifndef MINIMAL_BUILD
-				k8s_api = new string();
-				mesos_api = new string();
+				k8s_api = new std::string();
+				mesos_api = new std::string();
 #endif // MINIMAL_BUILD
 				break;
 			case 's':
@@ -576,7 +596,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 						break;
 					}
 
-					string optname = string(long_options[long_index].name);
+					std::string optname = std::string(long_options[long_index].name);
 					if(optname == "version")
 					{
 						printf("sysdig version %s\n", SYSDIG_VERSION);
@@ -586,12 +606,18 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					else if(optname == "interactive")
 					{
 						is_interactive = true;
-						output_type = sinsp_table::OT_JSON;
+						output_type = chisel_table::OT_JSON;
 					}
 					else if(optname == "large-environment")
 					{
 						inspector->set_large_envs(true);
 					}
+#ifdef HAS_MODERN_BPF
+					else if(optname == "cpus-for-each-buffer")
+					{
+						opener.bpf.cpus_for_each_syscall_buffer = sinsp_numparser::parsed16(optarg);
+					}
+#endif
 #ifdef HAS_CAPTURE
 #ifndef MINIMAL_BUILD
 					else if(optname == "cri")
@@ -610,7 +636,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					}
 					else if(optname == "raw")
 					{
-						output_type = sinsp_table::OT_RAW;
+						output_type = chisel_table::OT_RAW;
 					}
 					else if(optname == "force-term-compat")
 					{
@@ -620,6 +646,13 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					{
 						json_first_row = sinsp_numparser::parsed32(optarg);
 					}
+#ifdef HAS_MODERN_BPF
+					else if(optname == "modern-bpf")
+					{
+						opener.bpf.enabled = true;
+						opener.bpf.modern = true;
+					}
+#endif
 					else if(optname == "to")
 					{
 						json_last_row = sinsp_numparser::parsed32(optarg);
@@ -634,7 +667,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					}
 					else if(optname == "page-faults")
 					{
-						page_faults = true;
+						opener.options.page_faults = true;
 					}
 				}
 				break;
@@ -643,6 +676,18 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 			}
 		}
 
+		if (list_plugins)
+		{
+			plugins.print_plugin_info_list(inspector);
+			printf("More detailed info about individual plugins can be printed with the --plugin-info option:\n");
+			printf(" Detailed info about a single plugin\n");
+			printf("   $ sysdig --plugin-info=dummy\n\n");
+			printf(" Detailed info about a single plugin with a given configuration\n");
+			printf("   $ sysdig -H dummy:'{\"jitter\":50}' --plugin-info=dummy\n\n");
+			delete inspector;
+			return sysdig_init_res(EXIT_SUCCESS);
+		}
+
 #ifdef HAS_CAPTURE
 		if(!cri_socket_path.empty())
 		{
@@ -650,15 +695,15 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 		}
 #endif
 
-		string filter;
+		std::string filter;
 
 		//
 		// If -l was specified, print the fields and exit
 		//
 		if(list_flds)
 		{
-			list_fields(false, false);
-
+			// todo(jasondellaluce): support source selection, verbosity, markdown
+			print_supported_fields(inspector, plugins, "", true, false);
 			res.m_res = EXIT_SUCCESS;
 			goto exit;
 		}
@@ -668,7 +713,6 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 		//
 		if(optind + n_filterargs < argc)
 		{
-#ifdef HAS_FILTERING
 			for(int32_t j = optind + n_filterargs; j < argc; j++)
 			{
 				filter += argv[j];
@@ -677,28 +721,18 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					filter += " ";
 				}
 			}
-#else
-			fprintf(stderr, "filtering not compiled.\n");
-			res.m_res = EXIT_FAILURE;
-			goto exit;
-#endif
 		}
 
-		if(!bpf)
+		if(!opener.bpf.enabled)
 		{
-			const char *probe = scap_get_bpf_probe_from_env();
+			const char *probe = getenv("SYSDIG_BPF_PROBE");
 			if(probe)
 			{
-				bpf = true;
-				bpf_probe = probe;
+				opener.bpf.enabled = true;
+				opener.bpf.probe = probe;
 			}
 		}
 
-		if(bpf)
-		{
-			inspector->set_bpf_probe(bpf_probe);
-		}
-
 		if(signal(SIGINT, signal_callback) == SIG_ERR)
 		{
 			fprintf(stderr, "An error occurred while setting SIGINT signal handler.\n");
@@ -724,7 +758,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 		// Initialize ncurses
 		//
 #ifndef NOCURSESUI
-		if(output_type == sinsp_table::OT_CURSES)
+		if(output_type == chisel_table::OT_CURSES)
 		{
 			//
 			// Check if terminal has mouse support
@@ -763,12 +797,12 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 		//
 		// Create the list of views
 		//
-		sinsp_view_manager view_manager;
+		chisel_view_manager view_manager;
 
 		//
 		// Scan the chisel list to load the Lua views, and add them to the list
 		//
-		vector<chisel_desc> chlist;
+		std::vector<chisel_desc> chlist;
 		sinsp_chisel::get_chisel_list(&chlist);
 
 		for(auto it : chlist)
@@ -792,7 +826,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					}
 				}
 
-				if(output_type != sinsp_table::OT_JSON)
+				if(output_type != chisel_table::OT_JSON)
 				{
 					if(std::find(it.m_viewinfo.m_tags.begin(),
 						it.m_viewinfo.m_tags.end(),
@@ -826,7 +860,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 			// Initialize the UI
 			//
 			sinsp_cursesui ui(inspector,
-				(infiles.size() != 0)? infiles[0] : "",
+				&opener,
 				(filter.size() != 0)? filter : "",
 				refresh_interval_ns,
 				print_containers,
@@ -872,7 +906,9 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				//
 				// We have a file to open
 				//
-				inspector->open(infiles[j]);
+				opener.savefile.enabled = true;
+				opener.savefile.path = infiles[j];
+				opener.open(inspector);
 			}
 			else
 			{
@@ -880,64 +916,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				{
 					break;
 				}
-
-				//
-				// No file to open, this is a live capture
-				//
-#if defined(HAS_CAPTURE)
-				bool open_success = true;
-
-				try
-				{
-					inspector->open("");
-				}
-				catch(const sinsp_exception& e)
-				{
-					open_success = false;
-				}
-
-#ifndef _WIN32
-				//
-				// Starting the live capture failed, try to load the driver with
-				// modprobe.
-				//
-				if(!open_success)
-				{
-					open_success = true;
-
-					if(bpf)
-					{
-						if(bpf_probe.empty())
-						{
-							if(system("scap-driver-loader bpf"))
-							{
-								fprintf(stderr, "Unable to load the BPF probe\n");
-							}
-						}
-					}
-					else
-					{
-						if(system("modprobe " DRIVER_NAME " > /dev/null 2> /dev/null"))
-						{
-							fprintf(stderr, "Unable to load the driver\n");
-						}
-					}
-
-					inspector->open("");
-				}
-#endif // _WIN32
-#else // HAS_CAPTURE
-				//
-				// Starting live capture
-				// If this fails on Windows and OSX, don't try with any driver
-				//
-				inspector->open("");
-#endif // HAS_CAPTURE
-
-				//
-				// Enable gathering the CPU from the kernel module
-				//
-				inspector->set_get_procs_cpu_from_driver(true);
+				opener.open(inspector);
 			}
 
 			//
@@ -956,11 +935,6 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				inspector->enable_tracers_capture();
 			}
 
-			if(page_faults)
-			{
-				inspector->enable_page_faults();
-			}
-
 #ifndef MINIMAL_BUILD
 			//
 			// run k8s, if required
@@ -971,7 +945,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				{
 					if(char* k8s_cert_env = getenv("SYSDIG_K8S_API_CERT"))
 					{
-						k8s_api_cert = new string(k8s_cert_env);
+						k8s_api_cert = new std::string(k8s_cert_env);
 					}
 				}
 				inspector->init_k8s_client(k8s_api, k8s_api_cert, node_name);
@@ -986,10 +960,10 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					{
 						if(char* k8s_cert_env = getenv("SYSDIG_K8S_API_CERT"))
 						{
-							k8s_api_cert = new string(k8s_cert_env);
+							k8s_api_cert = new std::string(k8s_cert_env);
 						}
 					}
-					k8s_api = new string(k8s_api_env);
+					k8s_api = new std::string(k8s_api_env);
 					inspector->init_k8s_client(k8s_api, k8s_api_cert, node_name);
 				}
 				else
@@ -1012,7 +986,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 			{
 				if(mesos_api_env != NULL)
 				{
-					mesos_api = new string(mesos_api_env);
+					mesos_api = new std::string(mesos_api_env);
 					inspector->init_mesos_client(mesos_api);
 				}
 			}
@@ -1020,7 +994,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 			mesos_api = 0;
 #endif // MINIMAL_BUILD
 
-			if(output_type == sinsp_table::OT_JSON)
+			if(output_type == chisel_table::OT_JSON)
 			{
 				printf("{\"slices\": [\n");
 				if(display_view != "dig" && display_view != "echo")
@@ -1036,19 +1010,19 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				cnt,
 				&ui);
 
-			if(output_type == sinsp_table::OT_JSON)
+			if(output_type == chisel_table::OT_JSON)
 			{
 				printf("]}\n");
 				//printf("%c", EOF);
 			}
 
 			//
-			// Done. Close the capture.
+			// Done. Close the inspector.
 			//
 			inspector->close();
 		}
 	}
-	catch(const sinsp_capture_interrupt_exception&)
+	catch(const chisel_capture_interrupt_exception&)
 	{
 	}
 	catch(const scap_open_exception& e)
@@ -1077,7 +1051,7 @@ exit:
 	// Restore the original screen
 	//
 #ifndef NOCURSESUI
-	if(output_type == sinsp_table::OT_CURSES)
+	if(output_type == chisel_table::OT_CURSES)
 	{
 		endwin();
 	}
@@ -1085,7 +1059,7 @@ exit:
 
 	if(errorstr != "")
 	{
-		cerr << errorstr << endl;
+		std::cerr << errorstr << std::endl;
 	}
 
 	return res;
